@@ -1,9 +1,18 @@
+from django.conf import settings
 from jsonapi.resource import Resource
 from jsonapi.api import API
 
 api = API()
 
 
+@api.register
+class UserResource(Resource):
+    class Meta:
+        model = settings.AUTH_USER_MODEL
+        authenticators = [Resource.AUTHENTICATORS.SESSION]
+        fieldnames_exclude = 'password',
+
+
 @api.register
 class AuthorResource(Resource):
     class Meta:
